@@ -57,21 +57,27 @@ def DELETE(func):
 
 # Pull config from config.ini
 class StatusCastAPIDriver:
-    def __init__(self):
+    def __init__(self,password="",username="",base_url="",verify_ssl=False):
         # Parse the arguments
         # Optional
         self.args = self.parse_args()
 
-        # Set the config variables with the passed config file path
-        if self.args is not None and self.args.config is not None:
-            config = self.setConfig(filename=self.args.config[0])
-            self.password = config['statuscast']['password']
-            self.username = config['statuscast']['username']
-            self.base_url = config['statuscast']['base_url']
-            self.verify_ssl = True if config['status']['verify_ssl'] == "True" else False
-
-
-        # Initialize authorized session
+        if username == "":
+            print("You must provide a valid value for username, ({} is not a valid value)".format(username))
+            sys.exit(1)
+        elif password == "":
+            print("You must provide a valid value for password, ({} is not a valid value)".format(password))
+            sys.exit(1)
+        elif base_url == "":
+            print("You must provide a valid value for base_url, ({} is not a valid value)".format(base_url))
+            sys.exit(1)
+        elif verify_ssl == "":
+            print("You must provide a valid value for verify_ssl, ({} is not a valid value)".format(verify_ssl))
+            sys.exit(1)
+        self.password = password
+        self.username = username
+        self.base_url = base_url
+        self.verify_ssl = verify_ssl
         self.auth_session = self.initialize_session()
 
 
